==> caiviar-0.1.16.tar.gz: caiviar-0.1.16/demo/incoming.cpp <==
/* Simple.cpp

some demonstration routines for the SimpleCapi interface.

Part of the caiviar package. 

Copyright (c) 2002 MobileX AG, http://www.mobilexag.de
Copyright (c) 2002 Matthias Kramm <kramm@quiss.org>

This file is distributed under the GPL, see file COPYING for details. */

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifdef LINUX
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include "SimpleCapi.h"
#define Sleep usleep
#else
#include "stdafx.h"
#include "malloc.h"
#include "SimpleCapi.h"
#include "stdlib.h"
#include "stdio.h"
#include "windows.h"
#endif

class CapiTest {
public:
    void test_incoming() {
        SimpleCapi capi("SimpleCapi.properties");
        int line=capi.open ("33");
        if (line<0) {
            printf("no free line\n");
            return;
        }
        capi.acceptCalls (line);

        while(1) {
            int offline = 1;
            while(offline) {
                ISDNEvent event = capi.listen(line, 0);
                if(event.type == CAPI_EVENT_INCOMING) {
                    char*s = strdup(event.msisdn);
                    if(capi.answer (&event))
                        offline = 0;
                    else
                        printf("answering to msisdn %s didn't work out\n",s);
                    free(s);
                }
            }

            int playjob = capi.play (line, "welcome.wav");
            
            while (!done) {
                ISDNEvent event = capi.listen(line, 0);
                switch (event.type) {
                case CAPI_EVENT_HANGUP:
                    printf("hung up\n");
                    return;

                case CAPI_EVENT_DONE:
                    if (event.jobid == playjob)
                        playing = 0;
                    break;

                case CAPI_EVENT_DIALTONE:
                    if (playing) {
                        capi.stop (playjob);
                        playing = 0;
                    }
                   if(event.tone == '*') {
                        done =1;
                    }
                    break;
                default:
                    printf("Unexpected: %s\n", capi.eventToString (&event));
                    break;
                }
            }
            capi.hangup(line);
        }
    }
};

int main(int argn, char*argv[]) {
    CapiTest t;
    t.simple_epsody();
    return 0;
}

==> caiviar-0.1.17.tar.gz: caiviar-0.1.17/demo/incoming.cpp <==
/* Simple.cpp

some demonstration routines for the SimpleCapi interface.

Part of the caiviar package. 

Copyright (c) 2002 MobileX AG, http://www.mobilexag.de
Copyright (c) 2002 Matthias Kramm <kramm@quiss.org>

This file is distributed under the GPL, see file COPYING for details. */

#define LINUX
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include "../src/SimpleCapi.h"

class CapiTest {
public:
    void test_incoming() {
        SimpleCapi capi("SimpleCapi.properties", 0);
        int line=capi.open ("33");
        if (line<0) {
            printf("no free line\n");
            return;
        }
        capi.acceptCalls (line);

        while(1) {
            int offline = 1;
            while(offline) {
                ISDNEvent event = capi.listen(line, 0);
                if(event.type == CAPI_EVENT_INCOMING) {
                    char*s = strdup(event.msisdn);
                    if(capi.answer (&event))
                        offline = 0;
                    else
                        printf("answering to msisdn %s didn't work out\n",s);
                    free(s);
                }
            }

            int playjob = capi.play (line, "welcome.wav");
	    int done = 0;
	    int playing=1;
            
            while (!done) {
                ISDNEvent event = capi.listen(line, 0);
                switch (event.type) {
                case CAPI_EVENT_HANGUP:
                    printf("hung up\n");
                    return;

                case CAPI_EVENT_DONE:
                    if (event.jobid == playjob)
                        playing = 0;
                    break;

                case CAPI_EVENT_DIALTONE:
                    if (playing) { /* barge in */
                        capi.stop (playjob);
                        playing = 0;
                    }
                   if(event.tone == '*') {
                        done =1;
                    }
                    break;
                default:
                    printf("Unexpected: %s\n", capi.eventToString (&event));
                    break;
                }
            }
            capi.hangup(line);
        }
    }
};

int main(int argn, char*argv[]) {
    CapiTest t;
    t.test_incoming();
    return 0;
}
